@@ -123,9 +123,9 @@ constructStack.getEncryptionKey().addToResourcePolicy(policyStatement);
 |topicProps?|[`sns.TopicProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_sns.TopicProps.html)|User provided props to override the default props for the SNS Topic. |
 |existingEventBusInterface?|[`events.IEventBus`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_events.IEventBus.html)| Optional user-provided custom EventBus for construct to use. Providing both this and `eventBusProps` results an error.|
 |eventBusProps?|[`events.EventBusProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_events.EventBusProps.html)|Optional user-provided properties to override the default properties when creating a custom EventBus. Setting this value to `{}` will create a custom EventBus using all default properties. If neither this nor `existingEventBusInterface` is provided the construct will use the `default` EventBus. Providing both this and `existingEventBusInterface` results an error.|
-|enableEncryptionWithCustomerManagedKey?|`boolean`|Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct.|
-|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SNS Topic.|
-|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.KeyProps.html)|An optional, user provided properties to override the default properties for the KMS encryption key.|
+|enableEncryptionWithCustomerManagedKey?|`boolean`|If no key is provided, this flag determines whether the SNS Topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps.|
+|encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html)|An optional, imported encryption key to encrypt the SNS Topic with.|
+|encryptionKeyProps?|[`kms.KeyProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_kms.Key.html#construct-props)|Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS Topic with.|
 
 ## Pattern Properties
 
@@ -202,9 +202,9 @@ class EventbridgeToSns(
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
-        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
-        :param encryption_key: An optional, imported encryption key to encrypt the SQS queue, and SNS Topic. Default: - not specified.
-        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - True if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - None.
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS topic with. Default: - None
         :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
         :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
@@ -214,7 +214,21 @@ class EventbridgeToSns(
         :summary: Constructs a new instance of the EventbridgeToSns class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EventbridgeToSns.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
+                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventbridgeToSnsProps(
@@ -280,9 +294,9 @@ class EventbridgeToSnsProps:
     ) -> None:
         '''
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
-        :param enable_encryption_with_customer_managed_key: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
-        :param encryption_key: An optional, imported encryption key to encrypt the SQS queue, and SNS Topic. Default: - not specified.
-        :param encryption_key_props: Optional user-provided props to override the default props for the encryption key. Default: - Default props are used.
+        :param enable_encryption_with_customer_managed_key: If no key is provided, this flag determines whether the topic is encrypted with a new CMK or an AWS managed key. This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps. Default: - True if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
+        :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - None.
+        :param encryption_key_props: Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SNS topic with. Default: - None
         :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
         :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
         :param existing_topic_obj: Existing instance of SNS Topic object, providing both this and topicProps will cause an error.. Default: - Default props are used
@@ -297,7 +311,19 @@ class EventbridgeToSnsProps:
         if isinstance(topic_props, dict):
             topic_props = aws_cdk.aws_sns.TopicProps(**topic_props)
         if __debug__:
-            type_hints = typing.get_type_hints(EventbridgeToSnsProps.__init__)
+            def stub(
+                *,
+                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                existing_topic_obj: typing.Optional[aws_cdk.aws_sns.Topic] = None,
+                topic_props: typing.Optional[typing.Union[aws_cdk.aws_sns.TopicProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
             check_type(argname="argument enable_encryption_with_customer_managed_key", value=enable_encryption_with_customer_managed_key, expected_type=type_hints["enable_encryption_with_customer_managed_key"])
             check_type(argname="argument encryption_key", value=encryption_key, expected_type=type_hints["encryption_key"])
@@ -338,30 +364,29 @@ class EventbridgeToSnsProps:
     def enable_encryption_with_customer_managed_key(
         self,
     ) -> typing.Optional[builtins.bool]:
-        '''Use a KMS Key, either managed by this CDK app, or imported.
+        '''If no key is provided, this flag determines whether the topic is encrypted with a new CMK or an AWS managed key.
 
-        If importing an encryption key, it must be specified in
-        the encryptionKey property for this construct.
+        This flag is ignored if any of the following are defined: topicProps.masterKey, encryptionKey or encryptionKeyProps.
 
-        :default: - true (encryption enabled, managed by this CDK app).
+        :default: - True if topicProps.masterKey, encryptionKey, and encryptionKeyProps are all undefined.
         '''
         result = self._values.get("enable_encryption_with_customer_managed_key")
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
-        '''An optional, imported encryption key to encrypt the SQS queue, and SNS Topic.
+        '''An optional, imported encryption key to encrypt the SNS topic with.
 
-        :default: - not specified.
+        :default: - None.
         '''
         result = self._values.get("encryption_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
 
     @builtins.property
     def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
-        '''Optional user-provided props to override the default props for the encryption key.
+        '''Optional user provided properties to override the default properties for the KMS encryption key used to  encrypt the SNS topic with.
 
-        :default: - Default props are used.
+        :default: - None
         '''
         result = self._values.get("encryption_key_props")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
